pub struct NudConfiguration {
pub max_multicast_solicitations: Option<u16>,
pub max_unicast_solicitations: Option<u16>,
pub base_reachable_time: Option<i64>,
pub retrans_timer: Option<i64>,
/* private fields */
}Expand description
NudConfiguration for an interface.
This is scoped to IPv4 or IPv6 configuration by the Configuration type.
Fields
max_multicast_solicitations: Option<u16>The number of multicast solicitations before considering a neighbor unreachable.
Must be nonzero. ILLEGAL_ZERO_VALUE is returned on
[Control.SetConfiguration] otherwise.
max_unicast_solicitations: Option<u16>The number of unicast solicitations before considering a neighbor unreachable.
Must be nonzero.
base_reachable_time: Option<i64>A base duration for computing the random reachable time.
Reachable time is the duration for which a neighbor is considered reachable after a positive reachability confirmation is received. After this time, an entry will transition from REACHABLE to STALE state.
Referred to as “BaseReachableTime” by RFC 4861.
Must be greater than 0.
retrans_timer: Option<i64>The time between retransmissions of neighbor probes (Neighbor Solicitations for IPv6 and ARP requests for IPv4) to a neighbor when resolving the address or when probing the reachability of a neighbor as defined in [RFC 4861 section 6.3.2].
Referred to as “RetransTimer” by RFC 4861.
For IPv6, this value will not be used if the router has provided an override as per [RFC 4861 section 6.3.2]: The RetransTimer variable SHOULD be copied from the Retrans Timer field, if the received value is non-zero. Usually networks don’t advertise a non-zero RetransTimer, so this value will be used in those environments.
Must be greater than 0.