pub struct RouterSolicitationConfiguration {
pub max: Option<u8>,
/* private fields */
}Fields
max: Option<u8>Controls the maximum number of Router Solicitations that will be sent, as described in RFC 4861 Section 6.3.7.
Setting this value to zero disables Router Solicitations.
Note that setting this takes effect immediately. An interface that has already started sending router solicitations will see the limit change, and will stop or continue router solicitations, as appropriate.